==> snipe-it-5.1.8.zip: snipe-it-5.1.8/resources/lang/vi/mail.php <==
<?php

return array(
    'a_user_canceled' => 'Người dùng đã hủy bỏ một khoản mục yêu cầu trên trang web',
    'a_user_requested' => 'Người dùng đã yêu cầu một mục trên trang web',
    'accessory_name' => 'Tên Phụ Kiện:',
    'additional_notes' => 'Ghi chú bổ sung:',
    'admin_has_created' => 'Người quản trị đã tạo ra một tài khoản cho bạn trên trang web :web.',
    'asset' => 'Tài sản:',
    'asset_name' => 'Tên tài sản:',
    'asset_requested' => 'Tài sản được yêu cầu',
    'asset_tag' => 'Thẻ tài sản:',
    'assigned_to' => 'Cấp phát cho',
    'best_regards' => 'Trân trọng,',
    'canceled' => 'Đã hủy bỏ:',
    'checkin_date' => 'Ngày cấp phát:',
    'checkout_date' => 'Ngày thu hồi:',
    'click_to_confirm' => 'Vui lòng click chuột lên liên kết bên dưới để xác nhận tài khoản :web của Anh/Chị:',
    'click_on_the_link_accessory' => 'Vui lòng click chuột lên liên kết ở bên dưới để xác nhận Anh/Chị đã nhận phụ kiện.',
    'click_on_the_link_asset' => 'Vui lòng click chuột lên liên kết bên dưới để xác nhận Anh/Chị đã nhận tài sản.',
    'Confirm_Asset_Checkin' => 'Xác nhận cấp phát tài sản',
    'Confirm_Accessory_Checkin' => 'Xác nhận cấp phát Phụ kiện',
    'Confirm_accessory_delivery' => 'Xác nhận bàn giao phụ kiện',
    'Confirm_license_delivery' => 'Xác nhận chuyển giao giấy phép',
    'Confirm_asset_delivery' => 'Xác nhận bàn giao tài sản',
    'Confirm_consumable_delivery' => 'Xác nhận bàn giao tài sản tiêu hao',
    'current_QTY' => 'QTY hiện tại',
    'Days' => 'Ngày',
    'days' => 'Ngày',
    'expecting_checkin_date' => 'Dự kiến ​​ngày Checkin:',
    'expires' => 'Hết hạn',
    'Expiring_Assets_Report' => 'Báo cáo tài sản đang hết hạn.',
    'Expiring_Licenses_Report' => 'Giấy phép Giấy phép hết hạn.',
    'hello' => 'xin chào',
    'hi' => 'Chào',
    'i_have_read' => 'Tôi đã đọc và đồng ý với các điều khoản sử dụng và đã nhận được mục này.',
    'item' => 'Mục:',
    'Item_Request_Canceled' => 'Yêu cầu Mặt hàng bị Hủy',
    'Item_Requested' => 'Yêu cầu',
    'link_to_update_password' => 'Vui lòng nhấp vào liên kết sau để cập nhật: mật khẩu web:',
    'login_first_admin' => 'Đăng nhập vào hệ thống Snipe-IT mới bằng các thông tin dưới đây:',
    'login' => 'Đăng nhập:',
    'Low_Inventory_Report' => 'Báo cáo tồn kho thấp',
    'min_QTY' => 'Min QTY',
    'name' => 'Tên',
    'new_item_checked' => 'Một mục mới đã được kiểm tra dưới tên của bạn, chi tiết dưới đây.',
    'password' => 'Mật khẩu:',
    'password_reset' => 'Đặt lại mật khẩu',

    'read_the_terms' => 'Vui lòng đọc các điều khoản sử dụng bên dưới.',
    'read_the_terms_and_click' => 'Vui lòng đọc các điều khoản sử dụng dưới đây và nhấp vào liên kết ở phía dưới để xác nhận rằng bạn đã đọc và đồng ý với các điều khoản sử dụng và đã nhận được nội dung.',
    'requested' => 'Yêu cầu:',
    'reset_link' => 'Liên kết Đặt lại Mật khẩu của bạn',
    'reset_password' => 'Nhấn vào đây để đặt lại mật khẩu của bạn:',
    'serial' => 'Serial - Seri',
    'supplier' => 'Nhà cung cấp',
    'tag' => 'Nhãn',
    'test_email' => 'Kiểm tra Email từ Snipe-IT',
    'test_mail_text' => 'Đây là một bài kiểm tra từ Hệ thống Quản lý Tài sản Snipe-IT. Nếu bạn nhận được điều này, mail đang làm việc :)',
    'the_following_item' => 'Mục dưới đây đã được kiểm tra:',
    'low_inventory_alert' => 'Có: mặt hàng tồn dưới mức tối thiểu hoặc sẽ sớm ở mức thấp. | Có nhiều: mặt hàng tồn dưới mức tồn kho tối thiểu hoặc sẽ sớm ở mức thấp.',
    'assets_warrantee_alert' => 'Có: tài sản có bảo hành sắp hết hạn vào ngày mai: threshold days. | Có nhiều: tài sản có bảo hành sắp hết hạn trong ngày mai: threshold days.',
    'license_expiring_alert' => 'Có: giấy phép bản quyền sắp hết hạn trong ngày mai:threshold days. | Có nhiều: giấy phép bản quyên sắp hết hạn trong lần tiếp theo: threshold days.',
    'to_reset' => 'Để đặt lại mật khẩu web của bạn, hãy hoàn thành biểu mẫu này:',
    'type' => 'Kiểu',
    'upcoming-audits' => 'Hiện có :count tài sản sẽ được xem xét trong :threshold này nữa.',
    'user' => 'Người dùng',
    'username' => 'Tên đăng nhập',
    'welcome' => 'Chào mừng: tên',
    'welcome_to' => 'Chào mừng đến với: web!',
    'your_credentials' => 'Thông tin về Snipe-IT của bạn',
    'Accessory_Checkin_Notification' => 'Phụ kiện đã cấp phát thành công',
    'Asset_Checkin_Notification' => 'Tài sản đã cấp phát thành công',
    'License_Checkin_Notification' => 'Giấy phép đã cấp phát thành công',
    'Expected_Checkin_Report' => 'Báo cáo mong muốn cấp phát tài sản',
    'Expected_Checkin_Notification' => 'Nhắn nhở: hạn chót cấp phát cho :name gần đến',
    'Expected_Checkin_Date' => 'Một tài sản đã thu hồi về cho bạn vì đã hoàn lại vào ngày :date',
    'your_assets' => 'Xen qua tài sản của bạn'
);

==> snipe-it-5.4.3.zip: snipe-it-5.4.3/resources/lang/vi/mail.php <==
<?php

return [
    'a_user_canceled' => 'Người dùng đã hủy bỏ một khoản mục yêu cầu trên trang web',
    'a_user_requested' => 'Người dùng đã yêu cầu một mục trên trang web',
    'accessory_name' => 'Tên Phụ Kiện:',
    'additional_notes' => 'Ghi chú bổ sung:',
    'admin_has_created' => 'Người quản trị đã tạo ra một tài khoản cho bạn trên trang web :web.',
    'asset' => 'Tài sản:',
    'asset_name' => 'Tên tài sản:',
    'asset_requested' => 'Tài sản được yêu cầu',
    'asset_tag' => 'Asset Tag',
    'assigned_to' => 'Cấp phát cho',
    'best_regards' => 'Trân trọng,',
    'canceled' => 'Đã hủy bỏ:',
    'checkin_date' => 'Ngày cấp phát:',
    'checkout_date' => 'Ngày thu hồi:',
    'click_to_confirm' => 'Vui lòng click chuột lên liên kết bên dưới để xác nhận tài khoản :web của Anh/Chị:',
    'click_on_the_link_accessory' => 'Vui lòng click chuột lên liên kết ở bên dưới để xác nhận Anh/Chị đã nhận phụ kiện.',
    'click_on_the_link_asset' => 'Vui lòng click chuột lên liên kết bên dưới để xác nhận Anh/Chị đã nhận tài sản.',
    'Confirm_Asset_Checkin' => 'Xác nhận cấp phát tài sản',
    'Confirm_Accessory_Checkin' => 'Xác nhận cấp phát Phụ kiện',
    'Confirm_accessory_delivery' => 'Xác nhận bàn giao phụ kiện',
    'Confirm_license_delivery' => 'Xác nhận chuyển giao giấy phép',
    'Confirm_asset_delivery' => 'Xác nhận bàn giao tài sản',
    'Confirm_consumable_delivery' => 'Xác nhận bàn giao tài sản tiêu hao',
    'current_QTY' => 'QTY hiện tại',
    'Days' => 'Ngày',
    'days' => 'Ngày',
    'expecting_checkin_date' => 'Dự kiến ​​ngày Checkin:',
    'expires' => 'Hết hạn',
    'Expiring_Assets_Report' => 'Báo cáo tài sản đang hết hạn.',
    'Expiring_Licenses_Report' => 'Giấy phép Giấy phép hết hạn.',
    'hello' => 'xin chào',
    'hi' => 'Chào',
    'i_have_read' => 'Tôi đã đọc và đồng ý với các điều khoản sử dụng và đã nhận được mục này.',
    'item' => 'Mục:',
    'Item_Request_Canceled' => 'Yêu cầu Mặt hàng bị Hủy',
    'Item_Requested' => 'Yêu cầu',
    'link_to_update_password' => 'Vui lòng nhấp vào liên kết sau để cập nhật: mật khẩu web:',
    'login_first_admin' => 'Đăng nhập vào hệ thống Snipe-IT mới bằng các thông tin dưới đây:',
    'login' => 'Đăng nhập:',
    'Low_Inventory_Report' => 'Báo cáo tồn kho thấp',
    'min_QTY' => 'Min QTY',
    'name' => 'Tên',
    'new_item_checked' => 'Một mục mới đã được kiểm tra dưới tên của bạn, chi tiết dưới đây.',
    'password' => 'Mật khẩu:',
    'password_reset' => 'Đặt lại mật khẩu',

    'read_the_terms' => 'Vui lòng đọc các điều khoản sử dụng bên dưới.',
    'read_the_terms_and_click' => 'Vui lòng đọc các điều khoản sử dụng dưới đây và nhấp vào liên kết ở phía dưới để xác nhận rằng bạn đã đọc và đồng ý với các điều khoản sử dụng và đã nhận được nội dung.',
    'requested' => 'Yêu cầu:',
    'reset_link' => 'Liên kết Đặt lại Mật khẩu của bạn',
    'reset_password' => 'Nhấn vào đây để đặt lại mật khẩu của bạn:',
    'serial' => 'Serial - Seri',
    'supplier' => 'Nhà cung cấp',
    'tag' => 'Nhãn',
    'test_email' => 'Kiểm tra Email từ Snipe-IT',
    'test_mail_text' => 'Đây là một bài kiểm tra từ Hệ thống Quản lý Tài sản Snipe-IT. Nếu bạn nhận được điều này, mail đang làm việc :)',
    'the_following_item' => 'Mục dưới đây đã được kiểm tra:',
    'low_inventory_alert' => 'Có: mặt hàng tồn dưới mức tối thiểu hoặc sẽ sớm ở mức thấp. | Có nhiều: mặt hàng tồn dưới mức tồn kho tối thiểu hoặc sẽ sớm ở mức thấp.',
    'assets_warrantee_alert' => 'There is :count asset with a warranty expiring in the next :threshold days.|There are :count assets with warranties expiring in the next :threshold days.',
    'license_expiring_alert' => 'Có: giấy phép bản quyền sắp hết hạn trong ngày mai:threshold days. | Có nhiều: giấy phép bản quyên sắp hết hạn trong lần tiếp theo: threshold days.',
    'to_reset' => 'Để đặt lại mật khẩu web của bạn, hãy hoàn thành biểu mẫu này:',
    'type' => 'Kiểu',
    'upcoming-audits' => 'Hiện có :count tài sản sẽ được xem xét trong :threshold này nữa.',
    'user' => 'Người dùng',
    'username' => 'Tên đăng nhập',
    'welcome' => 'Chào mừng: tên',
    'welcome_to' => 'Chào mừng đến với: web!',
    'your_credentials' => 'Thông tin về Snipe-IT của bạn',
    'Accessory_Checkin_Notification' => 'Phụ kiện đã cấp phát thành công',
    'Asset_Checkin_Notification' => 'Tài sản đã cấp phát thành công',
    'License_Checkin_Notification' => 'Giấy phép đã cấp phát thành công',
    'Expected_Checkin_Report' => 'Báo cáo mong muốn cấp phát tài sản',
    'Expected_Checkin_Notification' => 'Nhắn nhở: hạn chót cấp phát cho :name gần đến',
    'Expected_Checkin_Date' => 'Một tài sản đã thu hồi về cho bạn vì đã hoàn lại vào ngày :date',
    'your_assets' => 'Xen qua tài sản của bạn',
];
